{% extends "account/base.html" %}
{% load i18n %}
{% load allauth %}

{% block head_title %}{% trans "Sign Up Closed" %}{% endblock head_title %}
{% block content %}
<div class="flex flex-col items-center justify-center w-screen h-screen text-gray-700 bg-gray-200">
  <div class="flex flex-col items-center p-12 bg-white rounded shadow-lg md:w-7/12 xl:w-5/12">
    <h1 class="mb-5 text-3xl text-center">{% trans "Sign Up Closed" %}</h1>
    <p class="my-5">{% trans "We are sorry, but the sign up is currently closed." %}</p>
    {% include "account/_links.html" %}
  </div>
</div>
{% endblock content %}
